<?php
/**
 * FiloBlu srl
 *
 * @category   FiloBlu
 * @package    FiloBlu_ReCaptcha
 * @copyright  FiloBlu srl (http://www.filoblu.com)
 *
 */

namespace FiloBlu\ReCaptcha\Observer\Frontend;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\UrlInterface;
use FiloBlu\ReCaptcha\Api\ValidateInterface;
use FiloBlu\ReCaptcha\Helper\Data;
use Magento\Framework\Message\ManagerInterface;
use Magento\Framework\App\ActionFlag;
use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Config\ScopeConfigInterface;

class ContactFormObserver implements ObserverInterface
{
    protected $validateInterface;
    protected $helperData;
    protected $messageManager;
    protected $actionFlag;
    protected $urlInterface;
    protected $scopeConfig;

    public function __construct(
        ValidateInterface $validateInterface,
        Data $helperData,
        ManagerInterface $messageManager,
        ActionFlag $actionFlag,
        UrlInterface $urlInterface,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {
        $this->validateInterface = $validateInterface;
        $this->helperData = $helperData;
        $this->messageManager = $messageManager;
        $this->actionFlag = $actionFlag;
        $this->urlInterface = $urlInterface;
        $this->scopeConfig = $scopeConfig;
    }

    public function execute(Observer $observer)
    {

        $controller = $observer->getControllerAction();

        if (!$this->scopeConfig->getValue('filoblu_recaptcha/settings/contact_index_index')) {
            $url = $this->urlInterface->getUrl('contact/index/post');
            $controller->getResponse()->setRedirect($url);
            return;
        }


        if (!$this->validateInterface->validate()) {
            $this->messageManager->addError($this->helperData->getErrorDescription());
            $this->actionFlag->set('', Action::FLAG_NO_DISPATCH, true);

            $url = $this->urlInterface->getUrl('contact/index/index');

            $controller->getResponse()->setRedirect($url);
        }
    }
}
